#include "stdafx.h"
#include "m4iz.h"

// CM4iz
//
//	This class loads the m.magic IZ DLL. 
//	Version 4.1600a
//
CM4iz::CM4iz()
{
	m_hMIZ = LoadLibrary(_T("mgc4iz.dll"));

	if(m_hMIZ != NULL) 
	{
		InitializeIZ = (LPMIZINITIALIZE)GetProcAddress(m_hMIZ, "mizInitialize");
		Begin = (LPMIZBEGIN)GetProcAddress(m_hMIZ, "mizBegin");	
		GetFileVersion = (LPMIZGETFILEVERSION)GetProcAddress(m_hMIZ, "mizGetFileVersion");
	}
}

CM4iz::~CM4iz()
{
	UnloadDll();
}


// CM4iz o֐
int CM4iz::AreYouReady()
{
	return (m_hMIZ != NULL)? CMGC4IZ::yes : CMGC4IZ::no;
}

int CM4iz::Initialize(LPCTSTR lpszResource, BOOL bCRC)
{
	//
	//// Initialize
	//

	// \[XDLL  CRC sBCRC l(dwCode)ςKv -->
#if _DEBUG
	static const DWORD dwCode[3] = { 0xf287cbf8, 0x44cbd956, 0xffffffff };
#else
	static const DWORD dwCode[3] = { 0xea67fc68, 0x06944085, 0xffffffff };
#endif
	// <--

	DWORD				dwCheckCode;	
	INT					nN;
	CMGC4IZ::INI_DATA	miz;
	WCHAR szResourceFile[MAX_PATH];


	if(m_hMIZ == NULL)
		return CMGC4IZ::mizFailure;

	if(bCRC)
	{
		// \[XDLL  CRC sB
		if(lstrcmpi(lpszResource, _T("miz4enu.dll")) == 0)
			nN = 0;
		else if(lstrcmpi(lpszResource, _T("miz4jpn.dll")) == 0)
			nN = 1;
		else
			nN = 2;

		dwCheckCode = (nN != 2)? Begin(CMGC4IZ::cmdGetFileCrc, CT2W(lpszResource)) : 0;

		if(dwCheckCode != dwCode[nN])
			return CMGC4IZ::mizFailure;
	}

	wcscpy_s(szResourceFile, MAX_PATH, CT2W(lpszResource));
	miz.lpszResourceFile = szResourceFile;

	return InitializeIZ(&miz);
}

int CM4iz::LoadHtmlForm(const BOOL bJpn, const int nID)
{
	//
	//// Load the HTML form.
	//
	CMGC4IZ::HTML_RESOURCE hr;

	InitializeHtmlResource(bJpn, nID, &hr);
	return Begin(CMGC4IZ::cmdLoadForm, &hr);
}

void CM4iz::InitializeHtmlResource(	const BOOL bJpn, 
									const int nID,
									CMGC4IZ::LPHTML_RESOURCE lpHtmlResource )
{
	//
	//	Initialize the CMGC4IZ:HTML_RESOURCE structure.
	//
	//		\[X̃tH[CӂɍB\[X̃tH[Ǝ̂̕ςꍇA
	//		tH[Ƃ̃oCgw肷B̒lŁA|C^ړĂB
	//		tH[̐́ACMGC4IZ:formMAX ŌŒłBWtH[̏ꍇȉ̒lɂȂ
	//		ꂼtH[TCÝAz̎wʒułB

	lpHtmlResource->nID = nID;

	if(lpHtmlResource->nID == CMGC4IZ::idrHtmlForm1)
	{
		lpHtmlResource->nTotalLength
			= (bJpn)? CMGC4IZ::form1Length : CMGC4IZ::form1EnuLength;	// g[^TCY
		lpHtmlResource->nLength[CMGC4IZ::formMetadata1s]	= CMGC4IZ::formLengthMetadata1s;
		lpHtmlResource->nLength[CMGC4IZ::formMetadata2s]	= CMGC4IZ::formLengthMetadata2s;
		lpHtmlResource->nLength[CMGC4IZ::formStructure1]	
			= (bJpn)? CMGC4IZ::formLengthStructure1 : CMGC4IZ::formEnuLengthSrtructure1;
	}
	else
	{
		lpHtmlResource->nTotalLength
			= (bJpn)? CMGC4IZ::form0Length : CMGC4IZ::form0EnuLength;	// g[^TCY
		lpHtmlResource->nLength[CMGC4IZ::formMetadata1s]	= CMGC4IZ::formLengthDontUse;
		lpHtmlResource->nLength[CMGC4IZ::formMetadata2s]	= CMGC4IZ::formLengthDontUse;
		lpHtmlResource->nLength[CMGC4IZ::formStructure0]	
			= (bJpn)? CMGC4IZ::formLengthStructure0 : CMGC4IZ::formEnuLengthSrtructure0;
	}
	
	lpHtmlResource->nLength[CMGC4IZ::formheader]		= CMGC4IZ::formLengthHeader;
	lpHtmlResource->nLength[CMGC4IZ::formImage]			= CMGC4IZ::formLengthImage;
	lpHtmlResource->nLength[CMGC4IZ::formFieldsHeader]	= CMGC4IZ::formLengthFieldsHeader;
	lpHtmlResource->nLength[CMGC4IZ::formField]			= CMGC4IZ::formLengthField;
	lpHtmlResource->nLength[CMGC4IZ::formOther]			= CMGC4IZ::formLengthOther;
	lpHtmlResource->nLength[CMGC4IZ::formFreeOne]		= CMGC4IZ::formLengthFreeOne;
	lpHtmlResource->nLength[CMGC4IZ::formFooter]		= CMGC4IZ::formLengthFooter;
	lpHtmlResource->nLength[CMGC4IZ::formMetadata0s]	= CMGC4IZ::formLengthMetadata0s;		
}

int CM4iz::UnloadResource()
{
	INT			 nResult;
	CMGC4IZ::INI_DATA miz;
	
	miz.lpszResourceFile = new WCHAR[2];
	miz.lpszResourceFile[0] = 0; // The resource DLL is unloaded, if this parameter is set to zero.
	nResult = InitializeIZ(&miz);
	delete [] miz.lpszResourceFile;

	return nResult;
}

void CM4iz::UnloadDll()
{
	if(m_hMIZ != NULL) 
	{
		FreeLibrary(m_hMIZ);
		m_hMIZ = NULL;
	}
}